==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/core/ilegend.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ILEGEND_H
#define ILEGEND_H


#include <vtkLegendBoxActor.h>


#include "ipointermacro.h"

class iOverlayHelper;
class iRenderTool;


class iLegend: public vtkLegendBoxActor
{
	
	IPOINTER_AS_USER(OverlayHelper);

public:
	
	vtkTypeMacro(iLegend,vtkLegendBoxActor);
	static iLegend* New(iRenderTool *rv = 0);
	
	virtual int RenderOverlay(vtkViewport *vp);
	virtual int RenderOpaqueGeometry(vtkViewport *vp);
	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
	
	virtual void ReleaseGraphicsResources(vtkWindow *win);

protected:

	virtual ~iLegend();

private:
	
	iLegend(iRenderTool *rv);
	
	float mUnmagx1[2], mUnmagx2[2];
};

#endif // ILEGEND_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/core/ilegend.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ILEGEND_H
#define ILEGEND_H


#include "igenericprop.h"
#include <vtkLegendBoxActor.h>


#include "ipointermacro.h"

class iOverlayHelper;
class iRenderTool;


class iLegend: public iGenericProp<vtkLegendBoxActor>
{
	
	IPOINTER_AS_USER(OverlayHelper);

public:
	
	vtkTypeMacro(iLegend,vtkLegendBoxActor);
	static iLegend* New(iRenderTool *rv = 0);

protected:

	virtual ~iLegend();

	virtual void UpdateGeometry(vtkViewport *vp);
	virtual void UpdateOverlay(vtkViewport *vp);
	virtual void Reset();

private:
	
	iLegend(iRenderTool *rv);
	
	float mUnmagx1[2], mUnmagx2[2];
};

#endif // ILEGEND_H
